@@ -170,21 +170,11 @@ YelpBase *
 yelp_base_new (void)
 {
         YelpBase     *base;
-	/* YelpBasePriv *priv; */
 	
         base = g_object_new (YELP_TYPE_BASE, NULL);
-	/* priv = base->priv; */
 	
 	yelp_toc_pager_init ();
 
-	/*
-	yelp_scrollkeeper_init (priv->toc_tree, &priv->index);
-	yelp_man_init (base->priv->toc_tree, &priv->index);
-	yelp_info_init (base->priv->toc_tree, &priv->index);
-	
-	priv->index = g_list_sort (priv->index, yelp_section_compare);
-	*/
-
         return base;
 }
 
